@@ -489,7 +489,7 @@ data_device_data_offer (void                  *data,
 static void
 data_device_enter (void                  *data,
                    struct wl_data_device *data_device,
-                   uint32_t               time,
+                   uint32_t               serial,
                    struct wl_surface     *surface,
                    int32_t                x,
                    int32_t                y,
@@ -497,8 +497,8 @@ data_device_enter (void                  *data,
 {
   GdkWaylandDeviceData *device = (GdkWaylandDeviceData *)data;
 
-  g_debug (G_STRLOC ": %s data_device = %p time = %d, surface = %p, x = %d y = %d, offer = %p",
-           G_STRFUNC, data_device, time, surface, x, y, offer);
+  g_debug (G_STRLOC ": %s data_device = %p serial = %u, surface = %p, x = %d y = %d, offer = %p",
+           G_STRFUNC, data_device, serial, surface, x, y, offer);
 
   /* Retrieve the DataOffer associated with with the wl_data_offer - this
    * association is made when the listener is attached.
@@ -1668,7 +1668,7 @@ gdk_wayland_device_offer_selection_content (GdkDevice
 
   wl_data_device_set_selection (device->data_device,
                                 offer->source,
-                                _wl_time_now ());
+                                _gdk_wayland_display_get_serial (display_wayland));
 
   device->selection_offer_out = offer;
 
