@@ -814,6 +814,8 @@ gdk_window_impl_wayland_finalize (GObject *object)
   if (impl->cursor)
     g_object_unref (impl->cursor);
 
+  g_free (impl->title);
+
   G_OBJECT_CLASS (_gdk_window_impl_wayland_parent_class)->finalize (object);
 }
 
@@ -1269,8 +1271,11 @@ gdk_window_wayland_get_root_coords (GdkWindow *window,
 
   _gdk_wayland_window_offset (window, &x_offset, &y_offset);
 
-  *root_x = x_offset + x;
-  *root_y = y_offset + y;
+  if (root_x)
+    *root_x = x_offset + x;
+
+  if (root_y)
+    *root_y = y_offset + y;
 
   return 1;
 }
@@ -1500,7 +1505,8 @@ gdk_wayland_window_set_title (GdkWindow   *window,
 
   impl = GDK_WINDOW_IMPL_WAYLAND (window->impl);
 
-  impl->title = strdup (title);
+  g_free (impl->title);
+  impl->title = g_strdup (title);
 }
 
 static void
@@ -2020,6 +2026,46 @@ gdk_wayland_window_get_scale_factor (GdkWindow *window)
   return impl->scale;
 }
 
+static struct wl_region *
+wl_region_from_cairo_region (GdkWaylandDisplay *display,
+                             cairo_region_t    *region)
+{
+  struct wl_region *wl_region;
+  int i, n_rects;
+
+  wl_region = wl_compositor_create_region (display->compositor);
+  if (wl_region == NULL)
+    return NULL;
+
+  n_rects = cairo_region_num_rectangles (region);
+  for (i = 0; i < n_rects; i++)
+    {
+      cairo_rectangle_int_t rect;
+      cairo_region_get_rectangle (region, i, &rect);
+      wl_region_add (wl_region, rect.x, rect.y, rect.width, rect.height);
+    }
+
+  return wl_region;
+}
+
+static void
+gdk_wayland_window_set_opaque_region (GdkWindow      *window,
+                                      cairo_region_t *region)
+{
+  GdkWindowImplWayland *impl = GDK_WINDOW_IMPL_WAYLAND (window->impl);
+  struct wl_region *wl_region;
+
+  if (GDK_WINDOW_DESTROYED (window))
+    return;
+
+  wl_region = wl_region_from_cairo_region (GDK_WAYLAND_DISPLAY (gdk_window_get_display (window)), region);
+  if (wl_region == NULL)
+    return;
+
+  wl_surface_set_opaque_region (impl->surface, wl_region);
+  wl_region_destroy (wl_region);
+}
+
 
 static void
 _gdk_window_impl_wayland_class_init (GdkWindowImplWaylandClass *klass)
@@ -2109,6 +2155,7 @@ _gdk_window_impl_wayland_class_init (GdkWindowImplWaylandClass *klass)
   impl_class->change_property = gdk_wayland_window_change_property;
   impl_class->delete_property = gdk_wayland_window_delete_property;
   impl_class->get_scale_factor = gdk_wayland_window_get_scale_factor;
+  impl_class->set_opaque_region = gdk_wayland_window_set_opaque_region;
 }
 
 
