@@ -850,6 +850,7 @@ static void atk_component_interface_init (AtkComponentIface *iface);
 static void atk_selection_interface_init (AtkSelectionIface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (GtkIconViewAccessible, gtk_icon_view_accessible, GTK_TYPE_CONTAINER_ACCESSIBLE,
+                         G_ADD_PRIVATE (GtkIconViewAccessible)
                          G_IMPLEMENT_INTERFACE (ATK_TYPE_COMPONENT, atk_component_interface_init)
                          G_IMPLEMENT_INTERFACE (ATK_TYPE_SELECTION, atk_selection_interface_init))
 
@@ -1336,16 +1337,12 @@ gtk_icon_view_accessible_class_init (GtkIconViewAccessibleClass *klass)
   atk_class->get_n_children = gtk_icon_view_accessible_get_n_children;
   atk_class->ref_child = gtk_icon_view_accessible_ref_child;
   atk_class->initialize = gtk_icon_view_accessible_initialize;
-
-  g_type_class_add_private (klass, sizeof (GtkIconViewAccessiblePrivate));
 }
 
 static void
 gtk_icon_view_accessible_init (GtkIconViewAccessible *accessible)
 {
-  accessible->priv = G_TYPE_INSTANCE_GET_PRIVATE (accessible,
-                                                  GTK_TYPE_ICON_VIEW_ACCESSIBLE,
-                                                  GtkIconViewAccessiblePrivate);
+  accessible->priv = gtk_icon_view_accessible_get_instance_private (accessible);
 }
 
 static AtkObject*
