@@ -254,7 +254,7 @@
 #include "gtktypebuiltins.h"
 #include "gtkwindow.h"
 #include "gtkicontheme.h"
-#include "gtkstock.h"
+#include "deprecated/gtkstock.h"
 
 
 static void gtk_builder_class_init     (GtkBuilderClass *klass);
@@ -517,7 +517,7 @@ gtk_builder_get_parameters (GtkBuilder  *builder,
             {
               if (pspec->flags & G_PARAM_CONSTRUCT_ONLY)
                 {
-                  g_warning ("Failed to get constuct only property "
+                  g_warning ("Failed to get construct only property "
                              "%s of %s with value `%s'",
                              prop->name, object_name, prop->data);
                   continue;
@@ -1579,7 +1579,7 @@ gtk_builder_connect_signals_default (GtkBuilder    *builder,
   
       if (!g_module_symbol (args->module, handler_name, (gpointer)&func))
 	{
-	  g_warning ("Could not find signal handler '%s'", handler_name);
+	  g_warning ("Could not find signal handler '%s'.  Did you compile with -rdynamic?", handler_name);
 	  return;
 	}
     }
