@@ -44,8 +44,8 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 *tp++ = gdk_pixbuf_rotation_get_type();
 *tp++ = gdk_pixbuf_simple_anim_get_type();
 *tp++ = gdk_pixbuf_simple_anim_iter_get_type();
-*tp++ = gdk_property_state_get_type();
 *tp++ = gdk_prop_mode_get_type();
+*tp++ = gdk_property_state_get_type();
 *tp++ = gdk_rectangle_get_type();
 *tp++ = gdk_rgba_get_type();
 *tp++ = gdk_screen_get_type();
@@ -110,9 +110,9 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 *tp++ = gtk_accel_label_get_type();
 *tp++ = gtk_accel_map_get_type();
 *tp++ = gtk_accessible_get_type();
-*tp++ = gtk_actionable_get_type();
 *tp++ = gtk_action_get_type();
 *tp++ = gtk_action_group_get_type();
+*tp++ = gtk_actionable_get_type();
 *tp++ = gtk_activatable_get_type();
 *tp++ = gtk_adjustment_get_type();
 *tp++ = gtk_align_get_type();
@@ -234,14 +234,14 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 *tp++ = gtk_icon_theme_get_type();
 *tp++ = gtk_icon_view_drop_position_get_type();
 *tp++ = gtk_icon_view_get_type();
-*tp++ = gtk_image_get_type();
-*tp++ = gtk_image_menu_item_get_type();
-*tp++ = gtk_image_type_get_type();
 *tp++ = gtk_im_context_get_type();
 *tp++ = gtk_im_context_simple_get_type();
 *tp++ = gtk_im_multicontext_get_type();
 *tp++ = gtk_im_preedit_style_get_type();
 *tp++ = gtk_im_status_style_get_type();
+*tp++ = gtk_image_get_type();
+*tp++ = gtk_image_menu_item_get_type();
+*tp++ = gtk_image_type_get_type();
 *tp++ = gtk_info_bar_get_type();
 *tp++ = gtk_input_hints_get_type();
 *tp++ = gtk_input_purpose_get_type();
@@ -254,6 +254,8 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 *tp++ = gtk_level_bar_mode_get_type();
 *tp++ = gtk_license_get_type();
 *tp++ = gtk_link_button_get_type();
+*tp++ = gtk_list_box_get_type();
+*tp++ = gtk_list_box_row_get_type();
 *tp++ = gtk_list_store_get_type();
 *tp++ = gtk_lock_button_get_type();
 *tp++ = gtk_menu_bar_get_type();
@@ -333,12 +335,13 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 *tp++ = gtk_revealer_transition_type_get_type();
 *tp++ = gtk_scale_button_get_type();
 *tp++ = gtk_scale_get_type();
+*tp++ = gtk_scroll_step_get_type();
+*tp++ = gtk_scroll_type_get_type();
 *tp++ = gtk_scrollable_get_type();
 *tp++ = gtk_scrollable_policy_get_type();
 *tp++ = gtk_scrollbar_get_type();
 *tp++ = gtk_scrolled_window_get_type();
-*tp++ = gtk_scroll_step_get_type();
-*tp++ = gtk_scroll_type_get_type();
+*tp++ = gtk_search_bar_get_type();
 *tp++ = gtk_search_entry_get_type();
 *tp++ = gtk_selection_data_get_type();
 *tp++ = gtk_selection_mode_get_type();
@@ -357,15 +360,15 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 *tp++ = gtk_sort_type_get_type();
 *tp++ = gtk_spin_button_get_type();
 *tp++ = gtk_spin_button_update_policy_get_type();
-*tp++ = gtk_spinner_get_type();
 *tp++ = gtk_spin_type_get_type();
+*tp++ = gtk_spinner_get_type();
 *tp++ = gtk_stack_get_type();
 *tp++ = gtk_stack_switcher_get_type();
 *tp++ = gtk_stack_transition_type_get_type();
 *tp++ = gtk_state_flags_get_type();
 *tp++ = gtk_state_type_get_type();
-*tp++ = gtk_statusbar_get_type();
 *tp++ = gtk_status_icon_get_type();
+*tp++ = gtk_statusbar_get_type();
 *tp++ = gtk_style_context_get_type();
 *tp++ = gtk_style_get_type();
 *tp++ = gtk_style_properties_get_type();
@@ -393,15 +396,15 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 *tp++ = gtk_toggle_action_get_type();
 *tp++ = gtk_toggle_button_get_type();
 *tp++ = gtk_toggle_tool_button_get_type();
-*tp++ = gtk_toolbar_get_type();
-*tp++ = gtk_toolbar_space_style_get_type();
-*tp++ = gtk_toolbar_style_get_type();
 *tp++ = gtk_tool_button_get_type();
 *tp++ = gtk_tool_item_get_type();
 *tp++ = gtk_tool_item_group_get_type();
 *tp++ = gtk_tool_palette_drag_targets_get_type();
 *tp++ = gtk_tool_palette_get_type();
 *tp++ = gtk_tool_shell_get_type();
+*tp++ = gtk_toolbar_get_type();
+*tp++ = gtk_toolbar_space_style_get_type();
+*tp++ = gtk_toolbar_style_get_type();
 *tp++ = gtk_tooltip_get_type();
 *tp++ = gtk_tree_drag_dest_get_type();
 *tp++ = gtk_tree_drag_source_get_type();
