@@ -28,7 +28,7 @@ on_bookmark_clicked (GtkButton *button, gpointer data)
   chooser = gtk_file_chooser_dialog_new ("File Chooser Test",
                                          window,
                                          GTK_FILE_CHOOSER_ACTION_OPEN,
-                                         GTK_STOCK_CLOSE,
+                                         "_Close",
                                          GTK_RESPONSE_CLOSE,
                                          NULL);
 
@@ -120,7 +120,8 @@ change_header (GtkButton *button, gpointer data)
       gtk_style_context_add_class (gtk_widget_get_style_context (header), "titlebar");
       gtk_header_bar_set_title (GTK_HEADER_BAR (header), "Example header");
 
-      widget = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
+      widget = gtk_button_new_with_label ("_Close");
+      gtk_button_set_use_underline (GTK_BUTTON (widget), TRUE);
       gtk_style_context_add_class (gtk_widget_get_style_context (widget), "suggested-action");
       g_signal_connect (widget, "clicked", G_CALLBACK (gtk_main_quit), NULL);
 
